import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

//creates rectangles for each row
// Quantitative attributes
// Domain = Data space
// Range = screen space (pixel coords)

// Quantitative attributes
// Domain = Data space
// Range = screen space (pixel coords)

const render = data => {
  
  const xValue = d => d.population;
  const yValue = d => d.country;
  const margin = {top:100, right:100, bottom:100, left:100 };
  const innerWidth = width - margin.left - margin.right
  const innerHeight = height - margin.top - margin.bottom
  
  const xScale = scaleLinear() // maps domain onto range
  .domain([0,max(data, xValue)])
  .range([0, innerWidth]); // min max
  
  
  const yScale = scaleBand() // categorical variables
  .domain(data.map(yValue))
  .range([0, innerHeight]) // min max
  .padding(0.1);
  //const yAxis = axisLeft(yScale);
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`);
  
  //yAxis(g.append('g'));
  g.append('g').call(axisLeft(yScale));
  g.append('g').call(axisBottom(xScale))
  .attr('transform', `translate(0,${innerHeight})`);

  
  g.selectAll('rect') // currently empty set of rectangles
  .data(data) //the data, bound to empty rectangles. This is the 'd3 data join'
  .enter() // (enter) - creates 1 'slot' for each row
  .append('rect') //append rectangles to your data elements (update)
  	.attr('y', d => yScale(yValue(d)))
    .attr('width', d => xScale(xValue(d))) // dimensions of rectangles
    .attr('height', yScale.bandwidth());
};

csv('data.csv').then(data => { // => is the arrow function
  data.forEach(d => {
    d.population = +d.population * 1000;
    console.log(d.population);
  })
  render(data);
  //console.log(data) // 1 object per *row* of original table
});
// then is a promise